@@ -6,22 +6,24 @@ from functools import lru_cache
 from functools import partial
 from typing import Optional, Union, List
 
-from edgar.entities import (Company,
-                            CompanyData,
-                            CompanyFacts,
-                            CompanySearchResults,
-                            CompanyFilings,
-                            CompanyFiling,
-                            Entity,
-                            EntityData,
-                            find_company,
-                            get_entity,
-                            get_company_facts,
-                            get_company_tickers,
-                            get_icon_from_ticker,
-                            get_entity_submissions,
-                            get_ticker_to_cik_lookup,
-                            get_cik_lookup_data)
+from edgar.entity import (
+    Entity,
+    EntityData,
+    Company,
+    CompanyData,
+    CompanyFacts,
+    CompanySearchResults,
+    CompanyFilings,
+    CompanyFiling,
+    find_company,
+    get_entity,
+    get_company_facts,
+    get_company_tickers,
+    get_icon_from_ticker,
+    get_entity_submissions,
+    get_ticker_to_cik_lookup,
+    get_cik_lookup_data
+)
 from edgar._filings import (Filing,
                             Filings,
                             FilingHeader,
@@ -30,6 +32,8 @@ from edgar._filings import (Filing,
                             Attachments,
                             get_filings,
                             get_current_filings,
+                            get_all_current_filings,
+                            iter_current_filings_pages,
                             get_by_accession_number,
                             FilingHomepage)
 from edgar.core import (edgar_mode,
@@ -39,13 +43,13 @@ from edgar.core import (edgar_mode,
                         get_identity,
                         set_identity,
                         listify)
-from edgar.fundreports import FundReport, NPORT_FORMS
-from edgar.funds import Fund, FundSeries, get_fund, FundClass
+from edgar.funds.reports import FundReport, NPORT_FORMS
+from edgar.funds import FundCompany, FundSeries,  FundClass, find_fund
 from edgar.thirteenf import ThirteenF, THIRTEENF_FORMS
+from edgar.xbrl import XBRL
 from edgar.files.html import Document
-from edgar.xbrl import XBRLData
 from edgar.financials import Financials, MultiFinancials
-from edgar.storage import use_local_storage, is_using_local_storage, download_edgar_data, download_filings
+from edgar.storage import use_local_storage, is_using_local_storage, set_local_storage_path, download_edgar_data, download_filings
 
 # Another name for get_current_filings
 get_latest_filings = get_current_filings
@@ -66,8 +70,7 @@ get_portfolio_holding_filings = partial(get_filings, form=THIRTEENF_FORMS)
 
 
 @lru_cache(maxsize=16)
-def find(search_id: Union[str, int]) -> (
-        Union)[Filing, EntityData, CompanySearchResults, Fund, FundClass, FundSeries]:
+def find(search_id: Union[str, int]) -> Optional[Union[Filing, Entity, CompanySearchResults, FundCompany, FundClass, FundSeries]]:
     """This is an uber search function that can take a variety of search ids and return the appropriate object
         - accession number -> returns a Filing
         - CIK -> returns an Entity
@@ -82,14 +85,20 @@ def find(search_id: Union[str, int]) -> (
         return Entity(search_id)
     elif re.match(r"\d{10}-\d{2}-\d{6}", search_id):
         return get_by_accession_number(search_id)
-    elif re.match(r"\d{4,10}", search_id):
+    elif re.match(r"^\d{18}$", search_id): # accession number with no dashes
+        accession_number = search_id[:10] + "-" + search_id[10:12] + "-" + search_id[12:]
+        return get_by_accession_number(accession_number)
+    elif re.match(r"\d{4,10}$", search_id):
         return Entity(search_id)
     elif re.match(r"^[A-WYZ]{1,5}([.-][A-Z])?$", search_id):  # Ticker (including dot or hyphenated)
         return Entity(search_id)
     elif re.match(r"^[A-Z]{4}X$", search_id):  # Mutual Fund Ticker
-        return get_fund(search_id)
+        return find_fund(search_id)
     elif re.match(r"^[CS]\d+$", search_id):
-        return get_fund(search_id)
+        return find_fund(search_id)
+    elif re.match(r"^\d{6,}-", search_id):
+        # Probably an invalid accession number
+        return None
     else:
         return find_company(search_id)
 
