@@ -1,6 +1,7 @@
 from datetime import datetime
 from functools import lru_cache, partial
 from typing import Dict, List, Optional
+import re
 
 from rich import box
 from rich import print
@@ -12,7 +13,7 @@ from rich.tree import Tree
 
 from edgar._filings import Attachments, Attachment
 from edgar._markdown import MarkdownContent
-from edgar.core import datefmt
+from edgar.formatting import datefmt
 from edgar.files.html import Document
 from edgar.files.html_documents import HtmlDocument
 from edgar.files.htmltools import ChunkedDocument, chunks2df, detect_decimal_items, adjust_for_empty_items
@@ -51,15 +52,15 @@ class CompanyReport:
 
     @property
     def income_statement(self):
-        return self.financials.get_income_statement() if self.financials else None
+        return self.financials.income_statement() if self.financials else None
 
     @property
     def balance_sheet(self):
-        return self.financials.get_balance_sheet() if self.financials else None
+        return self.financials.balance_sheet() if self.financials else None
 
     @property
     def cash_flow_statement(self):
-        return self.financials.get_cash_flow_statement() if self.financials else None
+        return self.financials.cashflow_statement() if self.financials else None
 
     @property
     @lru_cache(1)
@@ -142,6 +143,8 @@ class ItemOnlyFilingStructure(FilingStructure):
 class TenK(CompanyReport):
     structure = FilingStructure({
         "PART I": {
+            # special case for 10-K
+            # Items 1 and 2. Business and Properties
             "ITEM 1": {
                 "Title": "Business",
                 "Description": "Overview of the company's business operations, products, services, and market environment."
@@ -205,6 +208,10 @@ class TenK(CompanyReport):
             "ITEM 9B": {
                 "Title": "Other Information",
                 "Description": "Any other relevant information not covered in other sections."
+            },
+            "ITEM 9C": {
+                "Title": "Disclosure Regarding Foreign Jurisdictions That Prevent Inspections",
+                "Description": "Disclosure Regarding Foreign Jurisdictions That Prevent Inspections."
             }
         },
         "PART III": {
@@ -235,6 +242,10 @@ class TenK(CompanyReport):
                 "Title": "Exhibits, Financial Statement Schedules",
                 "Description": "Legal documents and financial schedules that support the financial statements " +
                                "and disclosures."
+            },
+            "ITEM 16": {
+                "Title": "Form 10-K Summary",
+                "Description": "Form 10-K Summary"
             }
         }
     })
@@ -258,10 +269,40 @@ class TenK(CompanyReport):
     @property
     def directors_officers_and_governance(self):
         return self['Item 10']
-
+    
+    @property
+    @lru_cache(maxsize=1)
+    def chunked_document(self):
+        return ChunkedDocument(self._filing.html(), prefix_src=self._filing.base_dir)
+    
+    @lru_cache(maxsize=1)
+    def id_parse_document(self, markdown:bool=False):
+        from edgar.files.html_documents_id_parser import ParsedHtml10K
+        return ParsedHtml10K().extract_html(self._filing.html(), self.structure, markdown=markdown)
+            
     def __str__(self):
         return f"""TenK('{self.company}')"""
 
+    def __getitem__(self, item_or_part: str):
+        # Show the item or part from the filing document. e.g. Item 1 Business from 10-K or Part I from 10-Q
+        item_text = self.chunked_document[item_or_part]
+        if item_text:
+            item_text = item_text.rstrip()
+            last_line = item_text.split("\n")[-1]
+            if re.match(r'^\b(PART\s+[IVXLC]+)\b', last_line):
+                item_text = item_text.rstrip(last_line)
+        return item_text
+
+    def get_item_with_part(self, part: str, item: str, markdown:bool=True):
+        if not part:
+            return self.id_parse_document(markdown).get(item.lower())
+        # Show the item or part from the filing document. e.g. Item 1 Business from 10-K or Part I from 10-Q
+        item_text = self.chunked_document.get_item_with_part(part, item, markdown=markdown)
+        # remove first line or last line (redundant part information)
+        if not item_text or not item_text.strip():
+            return self.id_parse_document(markdown).get(part.lower(), {}).get(item.lower())
+        return item_text
+    
     def get_structure(self):
         # Create the main tree
         tree = Tree("📄 ")
@@ -384,6 +425,92 @@ class TenQ(CompanyReport):
 
     def __str__(self):
         return f"""TenQ('{self.company}')"""
+    
+    def __getitem__(self, item_or_part: str):
+        # Show the item or part from the filing document. e.g. Item 1 Business from 10-K or Part I from 10-Q
+        item_text = self.chunked_document[item_or_part]
+        return item_text
+    
+    def get_item_with_part(self, part: str, item: str, markdown:bool=True):
+        if not part:
+            return self.id_parse_document(markdown).get(part.lower(), {}).get(item.lower())
+        # Show the item or part from the filing document. e.g. Item 1 Business from 10-K or Part I from 10-Q
+        item_text = self.chunked_document.get_item_with_part(part, item, markdown=markdown)
+        # remove first line or last line (redundant part information)
+        if not item_text or not item_text.strip():
+            return self.id_parse_document(markdown).get(part.lower(), {}).get(item.lower())
+        return item_text
+    
+    @lru_cache(maxsize=1)
+    def id_parse_document(self, markdown:bool=True):
+        from edgar.files.html_documents_id_parser import ParsedHtml10Q
+        return ParsedHtml10Q().extract_html(self._filing.html(), self.structure, markdown=markdown)
+            
+    @property
+    @lru_cache(maxsize=1)
+    def chunked_document(self):
+        return ChunkedDocument(self._filing.html(), prefix_src=self._filing.base_dir)
+    
+    def get_structure(self):
+        # Create the main tree
+        tree = Tree("📄 ")
+
+        # Get the actual items from the filing
+        actual_items = self.items
+
+        # Create a mapping of uppercase to actual case items
+        case_mapping = {item.upper(): item for item in actual_items}
+
+        # Process each part in the structure
+        for part, items in self.structure.structure.items():
+            # Create a branch for each part
+            part_tree = tree.add(f"[bold blue]{part}[/]")
+
+            # Add items under each part
+            for item_key, item_data in items.items():
+                # Check if this item exists in the actual filing
+                if item_key in case_mapping:
+                    # Use the actual case from the filing
+                    actual_item = case_mapping[item_key]
+                    item_text = Text.assemble(
+                        (f"{actual_item:<7} ", "bold green"),
+                        (f"{item_data['Title']}", "bold"),
+                    )
+                else:
+                    # Item doesn't exist - show in grey with original structure case
+                    item_text = Text.assemble(
+                        (f"{item_key}: ", "dim"),
+                        (f"{item_data['Title']}", "dim"),
+                    )
+
+                part_tree.add(item_text)
+
+        return tree
+
+    def __rich__(self):
+        title = Text.assemble(
+            (f"{self.company}", "bold deep_sky_blue1"),
+            (" ", ""),
+            (f"{self.form}", "bold"),
+        )
+        periods = Text.assemble(
+            ("Period ending ", "grey70"),
+            (f"{datefmt(self.period_of_report, '%B %d, %Y')}", "bold"),
+            (" filed on ", "grey70"),
+            (f"{datefmt(self.filing_date, '%B %d, %Y')}", "bold"),
+        )
+        panel = Panel(
+            Group(
+                periods,
+                Padding(" ", (1, 0, 0, 0)),
+                self.get_structure(),
+                Padding(" ", (1, 0, 0, 0)),
+                self.financials or Text("No financial data available", style="italic")
+            ),
+            title=title,
+            box=box.ROUNDED,
+        )
+        return panel
 
 
 class TwentyF(CompanyReport):
@@ -678,8 +805,10 @@ class CurrentReport():
             exhibit_content = self._get_exhibit_content(exhibit)
 
             if exhibit_content:
+                # Remove text like [/she] and replace with (she) to prevent it being treated as rich markup
+                cleaned_content = re.sub(r'\[(/[^]]*)]', r'(\1)',exhibit_content)
                 title = Text.assemble(("Exhibit ", "bold gray54"), (exhibit.document_type, "bold green"))
-                renderables.append(Panel(exhibit_content,
+                renderables.append(Panel(cleaned_content,
                                          title=title,
                                          subtitle=Text(exhibit.description, style="gray54"),
                                          box=box.SIMPLE))
